==> libggi_1.99.2.0b2.1.orig.tar.gz: libggi-2.0b2.1/default/kgi/genkgi.h <==
/* $Id: genkgi.h,v 1.4 1999/04/12 21:59:33 marcus Exp $
******************************************************************************

   LibGGI - kgicon specific overrides for fbcon
   API header

   Copyright (C) 1998 Marcus Sundberg	[marcus@ggi-project.org]

   Permission is hereby granted, free of charge, to any person obtaining a
   copy of this software and associated documentation files (the "Software"),
   to deal in the Software without restriction, including without limitation
   the rights to use, copy, modify, merge, publish, distribute, sublicense,
   and/or sell copies of the Software, and to permit persons to whom the
   Software is furnished to do so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
   THE AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
   IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
   CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************************
*/

#include <unistd.h>
#include <sys/mman.h>

#include <ggi/internal/ggi-dl.h>
#include <ggi/display/fbdev.h>
#include <kgi/kgi.h>

#ifndef MAP_FAILED
#define MAP_FAILED ((void*)-1)
#endif

struct genkgi_priv {
	int     fd;
	ggi_gc *mapped_gc;
	ggifunc_drawline   *drawline;
	ggifunc_drawbox    *drawbox;
	ggifunc_copybox    *copybox;
	ggifunc_fillscreen *fillscreen;
};

#define GENKGI_PRIV(vis) ((struct genkgi_priv*)FBDEV_PRIV(vis)->accelpriv)

ggifunc_drawline	GGI_genkgi_drawline;
ggifunc_drawbox		GGI_genkgi_drawbox;
ggifunc_copybox		GGI_genkgi_copybox;
ggifunc_fillscreen	GGI_genkgi_fillscreen;

==> libggi-2.0b1.tar.gz: libggi-2.0b1/default/kgi/genkgi.h <==
/* $Id: genkgi.h,v 1.2 1998/11/19 01:37:39 marcus Exp $
******************************************************************************

   LibGGI - kgicon specific overrides for fbcon
   API header

   Copyright (C) 1998 Marcus Sundberg	[marcus@ggi-project.org]

   Permission is hereby granted, free of charge, to any person obtaining a
   copy of this software and associated documentation files (the "Software"),
   to deal in the Software without restriction, including without limitation
   the rights to use, copy, modify, merge, publish, distribute, sublicense,
   and/or sell copies of the Software, and to permit persons to whom the
   Software is furnished to do so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
   THE AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
   IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
   CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************************
*/

#include <unistd.h>
#include <sys/mman.h>

#include <ggi/internal/ggi-dl.h>
#include <kgi/kgi.h>

struct ggiarg_genkgi {
	int fd;
};

struct genkgi_priv {
	int     fd;
	ggi_gc *mapped_gc;
	ggifunc_drawline   *drawline;
	ggifunc_drawbox    *drawbox;
	ggifunc_copybox    *copybox;
	ggifunc_fillscreen *fillscreen;
};

extern int _ggi_genkgi_prividx;

#define GENKGI_PRIV(vis) ((struct genkgi_priv*)LIBGGI_DRVPRIV(vis,_ggi_genkgi_prividx))

ggifunc_drawline	GGI_genkgi_drawline;
ggifunc_drawbox		GGI_genkgi_drawbox;
ggifunc_copybox		GGI_genkgi_copybox;
ggifunc_fillscreen	GGI_genkgi_fillscreen;
